diff --git a/eng/Versions.props b/eng/Versions.props
index afd301504..0e67a21c2 100644
--- a/eng/Versions.props
+++ b/eng/Versions.props
@@ -8,15 +8,14 @@
5
0
1
- 00
+ 00
- $(VersionMajor).$(VersionMinor).$(VersionSDKMinor)$(VersionPatch)
+ $(VersionMajor).$(VersionMinor).$(VersionSDKMinor)$(VersionFeature)
alpha
1
$(VersionMajor).$(VersionMinor)
$(MajorMinorVersion).$(VersionSDKMinor)
- $(VersionPrefix).$(_BuildNumberLabels)
$(VersionPrefix)-$(PreReleaseVersionLabel)$(PreReleaseVersionIteration)-$(_BuildNumberLabels)
diff --git a/src/core-sdk-tasks/GenerateMsiVersion.cs b/src/core-sdk-tasks/GenerateMsiVersion.cs
index 3c03a0a00..f257c0f6b 100644
--- a/src/core-sdk-tasks/GenerateMsiVersion.cs
+++ b/src/core-sdk-tasks/GenerateMsiVersion.cs
@@ -9,7 +9,7 @@ namespace Microsoft.DotNet.Cli.Build
public class GenerateMsiVersion : Task
{
[Required]
- public int CommitCount { get; set; }
+ public int VersionRevision { get; set; }
[Required]
public int VersionMajor { get; set; }
@@ -30,7 +30,7 @@ namespace Microsoft.DotNet.Cli.Build
Major = VersionMajor,
Minor = VersionMinor,
Patch = VersionPatch,
- CommitCount = CommitCount
+ VersionRevision = VersionRevision
};
MsiVersion = buildVersion.GenerateMsiVersion();
diff --git a/src/redist/targets/BundledTemplates.targets b/src/redist/targets/BundledTemplates.targets
index 6c8edf449..553bca59c 100644
--- a/src/redist/targets/BundledTemplates.targets
+++ b/src/redist/targets/BundledTemplates.targets
@@ -1,10 +1,10 @@
-
+
$(AspNetCorePackageVersionFor31Templates.IndexOf('-'))
$(AspNetCorePackageVersionFor31Templates)
$(AspNetCorePackageVersionFor31Templates.Substring(0, $(AspNetCore31VersionPreReleaseSeparator)))
- $(AspNetCore31VersionMajorMinorPatchVersion).$(GitCommitCount)
+ $(AspNetCore31VersionMajorMinorPatchVersion).$(CombinedBuildNumberAndRevision)
$(AspNetCore31VersionMajorMinorPatchVersion)
$(BundledTemplates31InstallPath)-$(VersionSuffix)
$([MSBuild]::Add($(AspNetCore31VersionMajorMinorPatchVersion.IndexOf('.')), 1))
@@ -14,7 +14,7 @@
$(AspNetCorePackageVersionFor30Templates.IndexOf('-'))
$(AspNetCorePackageVersionFor30Templates)
$(AspNetCorePackageVersionFor30Templates.Substring(0, $(AspNetCore30VersionPreReleaseSeparator)))
- $(AspNetCore30VersionMajorMinorPatchVersion).$(GitCommitCount)
+ $(AspNetCore30VersionMajorMinorPatchVersion).$(CombinedBuildNumberAndRevision)
$(AspNetCore30VersionMajorMinorPatchVersion)
$(BundledTemplates30InstallPath)-$(VersionSuffix)
$([MSBuild]::Add($(AspNetCore30VersionMajorMinorPatchVersion.IndexOf('.')), 1))
@@ -24,7 +24,7 @@
$(AspNetCorePackageVersionFor22Templates.IndexOf('-'))
$(AspNetCorePackageVersionFor22Templates)
$(AspNetCorePackageVersionFor22Templates.Substring(0, $(AspNetCore22VersionPreReleaseSeparator)))
- $(AspNetCore22VersionMajorMinorPatchVersion).$(GitCommitCount)
+ $(AspNetCore22VersionMajorMinorPatchVersion).$(CombinedBuildNumberAndRevision)
$(AspNetCore22VersionMajorMinorPatchVersion)
$(BundledTemplates22InstallPath)-$(VersionSuffix)
$([MSBuild]::Add($(AspNetCore22VersionMajorMinorPatchVersion.IndexOf('.')), 1))
@@ -34,7 +34,7 @@
$(AspNetCorePackageVersionFor21Templates.IndexOf('-'))
$(AspNetCorePackageVersionFor21Templates)
$(AspNetCorePackageVersionFor21Templates.Substring(0, $(AspNetCore21VersionPreReleaseSeparator)))
- $(AspNetCore21VersionMajorMinorPatchVersion).$(GitCommitCount)
+ $(AspNetCore21VersionMajorMinorPatchVersion).$(CombinedBuildNumberAndRevision)
$(AspNetCore21VersionMajorMinorPatchVersion)
$(BundledTemplates21InstallPath)-$(VersionSuffix)
$([MSBuild]::Add($(AspNetCore21VersionMajorMinorPatchVersion.IndexOf('.')), 1))
diff --git a/src/redist/targets/GenerateMSIs.targets b/src/redist/targets/GenerateMSIs.targets
index d97c7f714..5ae9726ee 100644
--- a/src/redist/targets/GenerateMSIs.targets
+++ b/src/redist/targets/GenerateMSIs.targets
@@ -54,30 +54,25 @@
$(LayoutDirectory)$(ArtifactNameSdk)
$(LayoutDirectory)MSBuildExtensions-->
+
+
+
+ $(_PatchNumber)
+ $(VersionPrefix).$(CombinedBuildNumberAndRevision)
+
-
-
-
-
-
-
- $(GitCommitCount.PadLeft(6,'0'))
-
-
-
+ VersionPatch="$(VersionFeature)">
diff --git a/src/core-sdk-tasks/Utils/Version.cs b/src/core-sdk-tasks/Utils/Version.cs
index b7d4e7536..7444ed123 100644
--- a/src/core-sdk-tasks/Utils/Version.cs
+++ b/src/core-sdk-tasks/Utils/Version.cs
@@ -8,7 +8,7 @@ namespace Microsoft.DotNet.Cli.Build
public virtual int Major { get; set; }
public virtual int Minor { get; set; }
public virtual int Patch { get; set; }
- public virtual int CommitCount { get; set; }
+ public virtual int VersionRevision { get; set; }
public string GenerateMsiVersion()
{
@@ -22,11 +22,11 @@ namespace Microsoft.DotNet.Cli.Build
// CLI major -> 6 bits
// CLI minor -> 6 bits
// CLI patch -> 6 bits
// CLI commitcount -> 14 bits
var major = Major << 26;
var minor = Minor << 20;
var patch = Patch << 14;
- var msiVersionNumber = major | minor | patch | CommitCount;
+ var msiVersionNumber = major | minor | patch | VersionRevision;
var msiMajor = (msiVersionNumber >> 24) & 0xFF;
var msiMinor = (msiVersionNumber >> 16) & 0xFF;
@@ -22,11 +22,11 @@ namespace Microsoft.DotNet.Cli.Build
// CLI minor -> 6 bits
// CLI patch -> 6 bits
- // CLI commitcount -> 14 bits
+ // CLI VersionRevision -> 14 bits
var major = Major << 26;
var minor = Minor << 20;